summaryrefslogtreecommitdiff
path: root/framework/Web/UI/WebControls/TRepeatInfo.php
diff options
context:
space:
mode:
authorxue <>2006-04-12 12:18:24 +0000
committerxue <>2006-04-12 12:18:24 +0000
commit373d8acc503b94ea09823f49e2ab5e395eccc584 (patch)
treeb45dbde451c0a53405aaf9f43ba2dcd6047e044d /framework/Web/UI/WebControls/TRepeatInfo.php
parent64cc0b33281efbef56fbd6495f433906eda50636 (diff)
Merge from 3.0 branch till 898.
Diffstat (limited to 'framework/Web/UI/WebControls/TRepeatInfo.php')
-rw-r--r--framework/Web/UI/WebControls/TRepeatInfo.php38
1 files changed, 35 insertions, 3 deletions
diff --git a/framework/Web/UI/WebControls/TRepeatInfo.php b/framework/Web/UI/WebControls/TRepeatInfo.php
index 5f4fb825..10c49691 100644
--- a/framework/Web/UI/WebControls/TRepeatInfo.php
+++ b/framework/Web/UI/WebControls/TRepeatInfo.php
@@ -57,13 +57,16 @@ interface IRepeatInfoUser
* TRepeatInfo class.
* TRepeatInfo represents repeat information for controls like {@link TCheckBoxList}.
* The layout of the repeated items is specified via {@link setRepeatLayout RepeatLayout},
* which can be either 'Table' (default) or 'Flow'.
* A table layout uses HTML table cells to organize the items while
* a flow layout uses line breaks to organize the items.
* The number of columns used to display the items is specified via
* {@link setRepeatColumns RepeatColumns} property, while the {@link setRepeatDirection RepeatDirection}
* governs the order of the items being rendered.
*
+ * Note, the Raw layout does not contain any formatting tags and thus ignores
+ * the column and repeat direction settings.
+ *
* @author Qiang Xue <qiang.xue@gmail.com>
* @version $Revision: $ $Date: $
* @package System.Web.UI.WebControls
@@ -169,11 +172,12 @@ class TRepeatInfo extends TComponent
}
/**
* @param string how the repeated items should be displayed, using table or using line breaks. Defaults to 'Table'.
*/
public function setRepeatLayout($value)
{
- $this->_repeatLayout=TPropertyValue::ensureEnum($value,array('Table','Flow'));
+ $this->_repeatLayout=TPropertyValue::ensureEnum($value,array('Table','Flow','Raw'));
}
/**
@@ -192,6 +196,11 @@ class TRepeatInfo extends TComponent
$control->setCaptionAlign($this->_captionAlign);
}
}
+ else if($this->_repeatLayout==='Raw')
+ {
+ $this->renderRawContents($writer,$user);
+ return;
+ }
else
$control=new TWebControl;
$control->setID($user->getClientID());
@@ -210,6 +219,29 @@ class TRepeatInfo extends TComponent
}
/**
+ * Renders contents in raw format.
+ * @param THtmlWriter writer for the rendering purpose
+ * @param IRepeatInfoUser repeat information user
+ */
+ protected function renderRawContents($writer,$user)
+ {
+ if($user->getHasHeader())
+ $user->renderItem($writer,$this,'Header',-1);
+
+ // render items
+ $hasSeparators=$user->getHasSeparators();
+ $itemCount=$user->getItemCount();
+ for($i=0;$i<$itemCount;++$i)
+ {
+ $user->renderItem($writer,$this,'Item',$i);
+ if($hasSeparators && $i!=$itemCount-1)
+ $user->renderItem($writer,$this,'Separator',$i);
+ }
+ if($user->getHasFooter())
+ $user->renderItem($writer,$this,'Footer',-1);
+ }
+
+ /**
* Renders contents in horizontal repeat direction.
* @param THtmlWriter writer for the rendering purpose
* @param IRepeatInfoUser repeat information user
@@ -57,13 +57,16 @@ interface IRepeatInfoUser
* TRepeatInfo represents repeat information for controls like {@link TCheckBoxList}.
* The layout of the repeated items is specified via {@link setRepeatLayout RepeatLayout},
- * which can be either 'Table' (default) or 'Flow'.
+ * which can be either 'Table' (default), 'Flow' or 'Raw'.
* A table layout uses HTML table cells to organize the items while
* a flow layout uses line breaks to organize the items.
@@ -169,11 +172,12 @@ class TRepeatInfo extends TComponent
}
/**
- * @param string how the repeated items should be displayed, using table or using line breaks. Defaults to 'Table'.
+ * @param string how the repeated items should be displayed, using table or using line breaks.
+ * Valid values include 'Table', 'Flow' and 'Raw'.
*/
public function setRepeatLayout($value)